@@ -31,6 +31,8 @@ typedef struct _http_info_value_t {
 	const gchar   *request_uri;
 	const gchar   *referer_uri;
 	const gchar   *full_uri;
+	const gchar   *location_base_uri;
+	const gchar   *location_target;
 } http_info_value_t;
 
 /** information about a request and response on a HTTP conversation. */
@@ -52,13 +54,17 @@ typedef struct _http_req_res_t {
 /** Conversation data of a HTTP connection. */
 typedef struct _http_conv_t {
 	guint    response_code;
-	guint32	 startframe;	/* First frame of proxied connection */
+	guint32  req_res_num;	/**< The number of requests in the conversation. */
 	gchar   *http_host;
 	gchar   *request_method;
 	gchar   *request_uri;
-	/** the number of requests on the conversation. */
-	guint32  req_res_num;
-	guint8   upgrade;
+	gchar   *full_uri;
+
+	/* Fields related to proxied/tunneled/Upgraded connections. */
+	guint32	 startframe;	/* First frame of proxied connection */
+	int    	 startoffset;	/* Offset within the frame where the new protocol begins. */
+	dissector_handle_t next_handle;	/* New protocol */
+
 	gchar   *websocket_protocol;	/* Negotiated WebSocket protocol */
 	gchar   *websocket_extensions;	/* Negotiated WebSocket extensions */
 	/* Server address and port, known after first server response */
@@ -72,13 +78,16 @@ typedef enum _http_type {
 	HTTP_REQUEST,
 	HTTP_RESPONSE,
 	HTTP_NOTIFICATION,
-	HTTP_OTHERS
+	HTTP_OTHERS,
+	SIP_DATA            /* If the content is from the SIP dissector*/
 } http_type_t;
 
 /** Passed to dissectors called by the HTTP dissector. */
 typedef struct _http_message_info_t {
-	http_type_t type;      /* Message type; may be HTTP_OTHERS if not called by HTTP */
-	const char *media_str; /* Content-Type parameters */
+	http_type_t type;       /**< Message type; may be HTTP_OTHERS if not called by HTTP */
+	const char *media_str;  /**< Content-Type parameters */
+	const char *content_id; /**< Content-ID parameter */
+	void *data;             /**< The http_type is used to indicate the data transported */
 } http_message_info_t;
 
 #endif /* __PACKET_HTTP_H__ */
